==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cloudngfw/kotlin/inputs/GetFqdnListGlobalRulestackPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cloudngfw.kotlin.inputs

import com.pulumi.azurenative.cloudngfw.inputs.GetFqdnListGlobalRulestackPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property globalRulestackName GlobalRulestack resource name
 * @property name fqdn list name
 */
public data class GetFqdnListGlobalRulestackPlainArgs(
    public val globalRulestackName: String,
    public val name: String,
) : ConvertibleToJava<com.pulumi.azurenative.cloudngfw.inputs.GetFqdnListGlobalRulestackPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cloudngfw.inputs.GetFqdnListGlobalRulestackPlainArgs =
        com.pulumi.azurenative.cloudngfw.inputs.GetFqdnListGlobalRulestackPlainArgs.builder()
            .globalRulestackName(globalRulestackName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetFqdnListGlobalRulestackPlainArgs].
 */
@PulumiTagMarker
public class GetFqdnListGlobalRulestackPlainArgsBuilder internal constructor() {
    private var globalRulestackName: String? = null

    private var name: String? = null

    /**
     * @param value GlobalRulestack resource name
     */
    @JvmName("glqfclcdkplmvnwf")
    public suspend fun globalRulestackName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.globalRulestackName = mapped
    }

    /**
     * @param value fqdn list name
     */
    @JvmName("gkmuibvprumyblxi")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    internal fun build(): GetFqdnListGlobalRulestackPlainArgs = GetFqdnListGlobalRulestackPlainArgs(
        globalRulestackName = globalRulestackName ?: throw PulumiNullFieldException("globalRulestackName"),
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/cloudngfw/kotlin/inputs/GetFqdnListGlobalRulestackPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cloudngfw.kotlin.inputs

import com.pulumi.azurenative.cloudngfw.inputs.GetFqdnListGlobalRulestackPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property globalRulestackName GlobalRulestack resource name
 * @property name fqdn list name
 */
public data class GetFqdnListGlobalRulestackPlainArgs(
    public val globalRulestackName: String,
    public val name: String,
) : ConvertibleToJava<com.pulumi.azurenative.cloudngfw.inputs.GetFqdnListGlobalRulestackPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cloudngfw.inputs.GetFqdnListGlobalRulestackPlainArgs = com.pulumi.azurenative.cloudngfw.inputs.GetFqdnListGlobalRulestackPlainArgs.builder()
        .globalRulestackName(globalRulestackName.let({ args0 -> args0 }))
        .name(name.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetFqdnListGlobalRulestackPlainArgs].
 */
@PulumiTagMarker
public class GetFqdnListGlobalRulestackPlainArgsBuilder internal constructor() {
    private var globalRulestackName: String? = null

    private var name: String? = null

    /**
     * @param value GlobalRulestack resource name
     */
    @JvmName("rkjgedtiocxijrpe")
    public suspend fun globalRulestackName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.globalRulestackName = mapped
    }

    /**
     * @param value fqdn list name
     */
    @JvmName("kpsofuijdpwswlsn")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    internal fun build(): GetFqdnListGlobalRulestackPlainArgs = GetFqdnListGlobalRulestackPlainArgs(
        globalRulestackName = globalRulestackName ?: throw PulumiNullFieldException("globalRulestackName"),
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
